<?xml version="1.0" encoding="UTF-8"?>
<gui name="systemdgenie"
     version="5"
     xmlns="http://www.kde.org/standards/kxmlgui/1.0"
     xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
     xsi:schemaLocation="http://www.kde.org/standards/kxmlgui/1.0
                         http://www.kde.org/standards/kxmlgui/1.0/kxmlgui.xsd" >
    <MenuBar>
        <Menu name="file">
            <text>&amp;File</text>
        </Menu>
        <Menu name="view">
            <text>&amp;View</text>
            <Action name="refresh" />
        </Menu>
        <Menu name="daemon">
            <text>&amp;Daemon</text>
            <Action name="reload-daemon-system" />
            <Action name="reload-daemon-user" />
            <Separator/>
            <Action name="reexec-daemon-system" />
            <Action name="reexec-daemon-user" />
        </Menu>
        <Menu name="unit">
            <text>&amp;Unit</text>
            <Action name="start-unit" />
            <Action name="stop-unit" />
            <Action name="restart-unit" />
            <Action name="reload-unit" />
            <Separator/>
            <Action name="enable-unit" />
            <Action name="disable-unit" />
            <Separator/>
            <Action name="mask-unit" />
            <Action name="unmask-unit" />
            <Separator/>
            <Action name="edit-unitfile" />
        </Menu>
        
        <Menu name="session">
            <text>&amp;Session</text>
            <Action name="activate-session" />
            <Action name="terminate-session" />
            <Action name="lock-session" />
        </Menu>
    </MenuBar>
    
    <ToolBar name="unitToolBar">
        <text>Unit Toolbar</text>
        <Action name="start-unit" />
        <Action name="stop-unit" />
        <Action name="reload-unit" />
    </ToolBar>

    <ToolBar name="confFileToolBar">
        <text>Config File Toolbar</text>
        <Action name="edit-conffile" />
        <Action name="open-manpage" />
    </ToolBar>
    
    <Menu name="context_menu_units">
        <Action name="start-unit" />
        <Action name="stop-unit" />
        <Action name="restart-unit" />
        <Action name="reload-unit" />
        <Separator/>
        <Action name="enable-unit" />
        <Action name="disable-unit" />
        <Separator/>
        <Action name="mask-unit" />
        <Action name="unmask-unit" />
        <Separator/>
        <Action name="edit-unitfile" />
    </Menu>
    
    <Menu name="context_menu_conf">
        <Action name="edit-conffile" />
        <Action name="open-manpage" />
    </Menu>
    
    <Menu name="context_menu_session">
        <Action name="activate-session" />
        <Action name="terminate-session" />
        <Action name="lock-session" />
    </Menu>
</gui>
